# Search functionality for Seek

from BeautifulSoup import BeautifulSoup
import requests
import urllib

def search_engine(term, result=0):
    # TODO: Get engine preference from config.
    return search_duckduckgo(term, result)

# This doesn't work yet
def search_google(term, result=0):
    result = requests.get("https://www.google.com/#q=" + urllib.quote_plus(term))

def search_duckduckgo(term, result=0):
    search_result = requests.get('https://duckduckgo.com/html/?q=' + urllib.quote_plus(term))
    soup = BeautifulSoup(search_result.content)
  
    # Skip the ads. Sorry DDG.
    # There is probably a better way to do this using a better selector rather than looping. TODO.
    divs = soup.findAll('div', 'results_links')
    for div in divs:
        if 'web-result-sponsored' in div['class']:
            divs.remove(div)

    link = divs[result]
    link_url = link.findAll('a')[0]['href']

    return link_url



#! /usr/bin/env python

from clint import arguments
import requests
import urllib
import argparse

from pyglance import glance
from search import search_engine

# Really shouldn't do this.
DIFFBOT_API_TOKEN = '2efef432c72b5a923408e04353c39a7c'

def get_page_data(url):
    diffbot_url = 'http://api.diffbot.com/v2/article?url=' + urllib.quote_plus(url) + "&token=" + DIFFBOT_API_TOKEN
    page = requests.get(diffbot_url)
    data = page.json()

    if 'error' in data:
        print data['error']
        quit()

    return data

def print_body(data):
    
    if 'text'  in data:
        print data['text']
        print ""
        print data['title']
        print data['url'] 
    else:
        print "No usable text found."

def glance_body(data, speed=600):
    print data['title']
    print data['url'] 
    glance(data['text'], speed)

def get_parser():
    parser = argparse.ArgumentParser(description='Command line searching for incredibly lazy people.')
    parser.add_argument('query', metavar='QUERY', type=str, nargs='*',
            help='the question to answer')
    parser.add_argument('-p','--pos', help='select answer in specified position (default: 0)', default=0, type=int)
    parser.add_argument('-t','--text', help='display answer as plaintext', default=True, dest='plaintext', action='store_true')
    parser.add_argument('-g','--glance', help='display result in glance format', default=False, dest='glancemode', action='store_true')
    parser.add_argument('-s','--speed', help='WPM to glance at.', default=600, dest='speed', type=int)
    return parser

def command_line_runner():
    parser = get_parser()
    args = vars(parser.parse_args())
    if not args['query']:
        parser.print_help()
        return
    else:
        seek(args)

def seek(args):
    term = ' '.join(args['query']).replace('?', '') 
    link_url = search_engine(term, args['pos'])
    data = get_page_data(link_url)
    if args['glancemode']:
        glance_body(data, args['speed'])
    else:
        print_body(data)

if __name__ == '__main__':
    try:
        command_line_runner()
    except (KeyboardInterrupt, SystemExit):
        print "" 
        quit()
    except Exception, e:
        quit()
